.. :changelog:

History
-------

0.1.11 (2017-07-18)
++++++++++++++++++

* Include Overview model.
* Remove validator daprecated.
* Delete additional description.
* Change PhoneNumberField by IntegerField.
* Fix JobInfo foreign key.
* Add description to migrate.
* Add migrations files.
* Add details to run makemigrations and migrate.
* Add language register and include all ModelAdmin.
